Module arg

Module arg 

Structs

Arguments
Various arguments given to the fuzzer, typically provided by the cargo fuzzcheck command line tool.
DefaultArguments

Enums

ArgumentsError
FuzzerCommand
The task that the fuzzer is asked to perform.

Constants

ARTIFACTS_FLAG
COMMAND_FLAG
COMMAND_FUZZ
COMMAND_MINIFY_INPUT
COMMAND_READ
DETECT_INFINITE_LOOP_FLAG
INPUT_FILE_FLAG
IN_CORPUS_FLAG
MAX_DURATION_FLAG
MAX_INPUT_CPLX_FLAG
MAX_ITERATIONS_FLAG
NO_ARTIFACTS_FLAG
NO_IN_CORPUS_FLAG
NO_OUT_CORPUS_FLAG
NO_STATS_FLAG
OUT_CORPUS_FLAG
STATS_FLAG
STOP_AFTER_FIRST_FAILURE_FLAG

Functions

help
The “help” output of cargo-fuzzcheck
options_parser
The command line argument parser used by the fuzz target and cargo fuzzcheck